Name:          parquet
Version:       1.5.0
Release:       6%{?dist}
Summary:       Java readers/writers for columnar file formats to use with Map-Reduce
License:       ASL 2.0
# http://parquet.incubator.apache.org/
URL:           http://parquet.io/
# wget https://github.com/Parquet/parquet-mr/archive/parquet-1.5.0.tar.gz
# rm -r parquet-mr-parquet-1.5.0/doc/dremel_paper/*.png
# tar czf parquet-mr-parquet-1.5.0-clean.tar.gz parquet-mr-parquet-1.5.0
Source0:       %{name}-mr-%{name}-%{version}-clean.tar.gz
Source1:       parquet-tools.xml

BuildRequires: mvn(com.google.guava:guava)
BuildRequires: mvn(com.twitter:parquet-format)
BuildRequires: mvn(commons-cli:commons-cli)
BuildRequires: mvn(commons-codec:commons-codec)
BuildRequires: mvn(it.unimi.dsi:fastutil)
BuildRequires: mvn(log4j:log4j:1.2.17)
# avro 1.7.6
BuildRequires: mvn(org.apache.avro:avro)
BuildRequires: mvn(org.apache.avro:avro-maven-plugin)
BuildRequires: mvn(org.apache.hadoop:hadoop-common)
BuildRequires: mvn(org.apache.hadoop:hadoop-mapreduce-client-core)
BuildRequires: mvn(org.codehaus.jackson:jackson-core-asl)
BuildRequires: mvn(org.codehaus.jackson:jackson-mapper-asl)
BuildRequires: mvn(org.xerial.snappy:snappy-java)

%if 0
# Test deps
BuildRequires: mvn(com.carrotsearch:junit-benchmarks)
BuildRequires: mvn(com.h2database:h2)
BuildRequires: mvn(commons-httpclient:commons-httpclient)
BuildRequires: mvn(junit:junit)
%endif

BuildRequires: maven-local
BuildRequires: buildnumber-maven-plugin
BuildRequires: exec-maven-plugin
BuildRequires: libxslt
BuildRequires: docbook-dtds
BuildRequires: docbook-style-xsl

BuildArch:     noarch

%description
Parquet is a columnar storage format that supports nested data.
This provides the java implementation.

%package tools
Summary:       Command line that aid in the inspection of columnar file formats
Requires:      %{name} = %{version}-%{release}
Requires:      apache-commons-configuration
Requires:      apache-commons-lang
Requires:      apache-commons-logging
Requires:      avalon-framework
Requires:      avalon-logkit
Requires:      geronimo-jms
Requires:      hadoop-common
Requires:      httpcomponents-client
Requires:      httpcomponents-core
Requires:      javamail
Requires:      libthrift-java
Requires:      log4j12
Requires:      slf4j
Requires:      jboss-servlet-3.0-api


%description tools
Parquet-Tools contain java based command line tool that aid
in the inspection of Parquet files.

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n %{name}-mr-%{name}-%{version}
find . -name "*.jar" -print -delete
find . -name "*.class" -print -delete

# Disable copy of: fastutil jackson
%pom_remove_plugin :maven-shade-plugin
%pom_remove_plugin :maven-shade-plugin parquet-column

%pom_remove_plugin org.codehaus.mojo:buildnumber-maven-plugin

%pom_disable_module parquet-jackson
%pom_remove_dep :parquet-jackson parquet-hadoop

%pom_remove_dep :hadoop-client parquet-avro
%pom_remove_dep :hadoop-client parquet-hadoop
%pom_remove_dep :hadoop-client parquet-tools

%pom_add_dep org.apache.hadoop:hadoop-common:'${hadoop.version}':provided parquet-avro
%pom_add_dep org.apache.hadoop:hadoop-mapreduce-client-core:'${hadoop.version}':provided parquet-avro
%pom_add_dep org.apache.hadoop:hadoop-common:'${hadoop.version}':provided parquet-hadoop
%pom_add_dep org.apache.hadoop:hadoop-mapreduce-client-core:'${hadoop.version}':provided parquet-hadoop
%pom_add_dep org.apache.hadoop:hadoop-common:'${hadoop.version}':provided parquet-tools
%pom_add_dep org.apache.hadoop:hadoop-mapreduce-client-core:'${hadoop.version}':provided parquet-tools

# Unavailable deps, disabled for now
# # cascading:cascading-hadoop:2.5.1
%pom_disable_module parquet-cascading
%pom_disable_module parquet-pig
%pom_disable_module parquet-pig-bundle
# com.twitter:scrooge-core_2.9.2:3.8.0
%pom_disable_module parquet-scrooge
# com.twitter.elephantbird:elephant-bird-core,elephant-bird-pig:4.4
%pom_disable_module parquet-protobuf
%pom_disable_module parquet-thrift

%pom_disable_module parquet-test-hadoop2
%pom_disable_module parquet-hadoop-bundle
%pom_disable_module parquet-hive
%pom_disable_module parquet-hive-bundle

# Use org.semver:enforcer-rule:0.9.17
%pom_remove_plugin :maven-enforcer-plugin parquet-avro
%pom_remove_plugin :maven-enforcer-plugin parquet-cascading
%pom_remove_plugin :maven-enforcer-plugin parquet-column
%pom_remove_plugin :maven-enforcer-plugin parquet-common
%pom_remove_plugin :maven-enforcer-plugin parquet-encoding
%pom_remove_plugin :maven-enforcer-plugin parquet-generator
%pom_remove_plugin :maven-enforcer-plugin parquet-hadoop
%pom_remove_plugin :maven-enforcer-plugin parquet-tools

%build
# No test deps
%mvn_build -f

xsltproc \
 --nonet --stringparam man.output.quietly 1 \
 --stringparam funcsynopsis.style ansi \
 --stringparam man.authors.section.enabled 0 \
 --stringparam man.copyright.section.enabled 0 \
 /usr/share/sgml/docbook/xsl-stylesheets/manpages/docbook.xsl %{SOURCE1}

%install
%mvn_install

%jpackage_script parquet.tools.Main "" "" %{name}:%{name}-format:avalon-framework-api:avalon-logkit:commons-cli:commons-codec:commons-configuration:commons-lang:commons-logging:fastutil:geronimo-jms:guava:httpcomponents/httpclient:httpcomponents/httpcore:jackson/jackson-core-asl:jackson/jackson-mapper-asl:libthrift:log4j12-1.2.17:javamail/mail:jboss-servlet-3.0-api:snappy-java:slf4j/slf4j-api:hadoop/hadoop-common:hadoop/hadoop-auth %{name}-tools true

mkdir -p %{buildroot}%{_mandir}/man1
install -pm 644 %{name}-tools.1 %{buildroot}%{_mandir}/man1/

%files -f .mfiles
%doc CHANGES.md README.md
%license LICENSE NOTICE

%files tools
%{_bindir}/%{name}-tools
%{_mandir}/man1/%{name}-tools.*
%doc %{name}-tools/README.md
%license LICENSE %{name}-tools/NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE

%changelog
* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Apr 22 2015 Peter Robinson <pbrobinson@fedoraproject.org> 1.5.0-5
- ARMv7 now has hadoop

* Wed Jul 09 2014 gil cattaneo <puntogil@libero.it> 1.5.0-4
- add parquet-tools sub package

* Wed Jul 09 2014 gil cattaneo <puntogil@libero.it> 1.5.0-3
- fix summary
- remove images with unknow copyright

* Wed Jul 09 2014 gil cattaneo <puntogil@libero.it> 1.5.0-2
- avoid missing dep (Hadoop) on arm

* Wed Jul 09 2014 gil cattaneo <puntogil@libero.it> 1.5.0-1
- update to 1.5.0

* Wed Mar 05 2014 gil cattaneo <puntogil@libero.it> 1.4.3-1
- update to 1.4.3

* Wed Mar 05 2014 gil cattaneo <puntogil@libero.it> 1.3.2-1
- initial rpm
